using MWS.Model;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace MWS.Data.InterFace
{
    public interface IZigbee: IDapperHelper
    {
        Task<List<Zigbee>> GetModels(string keyword, string sortingProperty = "Id", bool ascending = false);
        List<Zigbee> GetPagingModels(string keyword, out int totalCount, int pageIndex = 1, int pageSize = 20, string sortingProperty = "Id", bool ascending = false);

        List<Zigbee> GetAll();

        List<Zigbee> GetAll(int device);

        int Delete(int Id);

        int Update(Zigbee zigbee);
    }
}
